@@ -14,7 +14,7 @@ use Cwd qw//;
 use Digest::MD5 qw//;
 require DBIx::Class;
 
-our $VERSION = '0.04005';
+our $VERSION = '0.04006';
 
 __PACKAGE__->mk_ro_accessors(qw/
                                 schema
@@ -39,6 +39,8 @@ __PACKAGE__->mk_ro_accessors(qw/
                                 result_namespace
                                 resultset_namespace
                                 default_resultset_class
+                                schema_base_class
+                                result_base_class
 
                                 db_schema
                                 _tables
@@ -120,6 +122,14 @@ L<Lingua::EN::Inflect::Number/to_PL>.
 As L</inflect_plural> above, but for singularizing relationship names.
 Default behavior is to utilize L<Lingua::EN::Inflect::Number/to_S>.
 
+=head2 schema_base_class
+
+Base class for your schema classes. Defaults to 'DBIx::Class::Schema'.
+
+=head2 result_base_class
+
+Base class for your table classes (aka result classes). Defaults to 'DBIx::Class'.
+
 =head2 additional_base_classes
 
 List of additional base classes all of your table classes will use.
@@ -253,7 +263,7 @@ sub new {
             if $self->{dump_overwrite};
 
     $self->{relbuilder} = DBIx::Class::Schema::Loader::RelBuilder->new(
-        $self->schema_class, $self->inflect_plural, $self->inflect_singular
+        $self->schema, $self->inflect_plural, $self->inflect_singular
     ) if !$self->{skip_relationships};
 
     $self;
@@ -289,10 +299,10 @@ sub _load_external {
     my $real_inc_path = Cwd::abs_path($inc_path);
     return if $real_inc_path eq $real_dump_path;
 
-    $class->require;
-    croak "Failed to load external class definition"
-        . " for '$class': $@"
-            if $@;
+    # must use $UNIVERSAL::require::ERROR, $@ is not safe. See RT #44444 --kane
+    $class->require or 
+        croak "Failed to load external class definition"
+            . " for '$class': $UNIVERSAL::require::ERROR";
 
     # If we make it to here, we loaded an external definition
     warn qq/# Loaded external class definition for '$class'\n/
@@ -445,6 +455,7 @@ sub _dump_to_dir {
     my $target_dir = $self->dump_directory;
 
     my $schema_class = $self->schema_class;
+    my $schema_base_class = $self->schema_base_class || 'DBIx::Class::Schema';
 
     croak "Must specify target directory for dumping!" if ! $target_dir;
 
@@ -453,7 +464,7 @@ sub _dump_to_dir {
     my $schema_text =
           qq|package $schema_class;\n\n|
         . qq|use strict;\nuse warnings;\n\n|
-        . qq|use base 'DBIx::Class::Schema';\n\n|;
+        . qq|use base '$schema_base_class';\n\n|;
 
     
     if ($self->use_namespaces) {
@@ -476,11 +487,13 @@ sub _dump_to_dir {
 
     $self->_write_classfile($schema_class, $schema_text);
 
+    my $result_base_class = $self->result_base_class || 'DBIx::Class';
+
     foreach my $src_class (sort keys %{$self->{_dump_storage}}) {
         my $src_text = 
               qq|package $src_class;\n\n|
             . qq|use strict;\nuse warnings;\n\n|
-            . qq|use base 'DBIx::Class';\n\n|;
+            . qq|use base '$result_base_class';\n\n|;
 
         $self->_write_classfile($src_class, $src_text);
     }
@@ -571,7 +584,7 @@ sub _use {
     foreach (@_) {
         warn "$target: use $_;" if $self->debug;
         $self->_raw_stmt($target, "use $_;");
-        $_->require or croak ($_ . "->require: $@");
+        $_->require or croak ($_ . "->require: $UNIVERSAL::require::ERROR");
         $evalstr .= "package $target; use $_;";
     }
     eval $evalstr if $evalstr;
@@ -587,7 +600,7 @@ sub _inject {
     warn "$target: use base qw/ $blist /;" if $self->debug && @_;
     $self->_raw_stmt($target, "use base qw/ $blist /;") if @_;
     foreach (@_) {
-        $_->require or croak ($_ . "->require: $@");
+        $_->require or croak ($_ . "->require: $UNIVERSAL::require::ERROR");
         $schema_class->inject_base($target, $_);
     }
 }
@@ -715,9 +728,11 @@ sub _load_relationships {
 
     foreach my $src_class (sort keys %$rel_stmts) {
         my $src_stmts = $rel_stmts->{$src_class};
-        foreach my $stmt (@$src_stmts) {
+        foreach my $stmt (@{$src_stmts->{stmts}}) {
             $self->_dbic_stmt($src_class,$stmt->{method},@{$stmt->{args}});
         }
+        $self->schema_class->register_class($src_stmts->{moniker}, $src_class);
+        $self->schema->register_class($src_stmts->{moniker}, $src_class) if $self->schema_class ne $self->schema;
     }
 }
 
